/*
* Plugin name:  ImageGen
*
* @author Notari Kevin
* @version 1.0
*/

(function () {
  CKEDITOR.plugins.add('ImageGen',
    {
      icons: 'ImageGenIcon',
      hidpi: true,
      init: function (editor) {
        CKEDITOR.dialog.add('ImageGenDialog', function (instance) {
          return {
            title: 'ImageGen',
            minWidth: 350,
            minHeight: 200,
            contents:
              [
                {
                  id: 'ImageGen',
                  expand: true,
                  elements: [
                    {
                      id: 'text',
                      type: 'text',
                      label: 'Text',
                      validate: CKEDITOR.dialog.validate.notEmpty("Text field is required !"),
                      default: editor.config.ImageGenButton_text,
                    },
                    {
                      type: 'hbox',
                      align: 'left',
                      widths: ['30%', '30%'],
                      children: [
                        {
                          id: 'width',
                          type: 'text',
                          label: 'width',
                          validate: CKEDITOR.dialog.validate.notEmpty("Width field is required !"),
                          width: '100px',
                          default: editor.config.ImageGenButton_width,
                        },
                        {
                          id: 'height',
                          type: 'text',
                          label: 'height',
                          validate: CKEDITOR.dialog.validate.notEmpty("Height field is required !"),
                          width: '100px',
                          default: editor.config.ImageGenButton_height,
                        },
                      ]
                    },

                    {
                      id: 'bg',
                      type: 'text',
                      label: 'Background color',
                      validate: CKEDITOR.dialog.validate.notEmpty("Background color field is required !"),
                      width: '100px',
                      default: editor.config.ImageGenButton_bg.substring(1),
                    },

                    {
                      id: 'color',
                      type: 'text',
                      label: 'Text color',
                      validate: CKEDITOR.dialog.validate.notEmpty("Text color field is required !"),
                      width: '100px',
                      default: editor.config.ImageGenButton_color.substring(1),
                    }
                  ]
                }
              ],
            onOk: function () {
              let img = instance.document.createElement('img');
              let width = this.getContentElement('ImageGen', 'width').getValue();
              let height = this.getContentElement('ImageGen', 'height').getValue();
              let bg = this.getContentElement('ImageGen', 'bg').getValue();
              let color = this.getContentElement('ImageGen', 'color').getValue();
              let text = this.getContentElement('ImageGen', 'text').getValue();
              img.setAttribute("width", width);
              img.setAttribute("height", height);
              img.setAttribute("bg", bg);
              img.setAttribute("color", color);
              img.setAttribute("alt", text);
              img.setAttribute("src", editor.config.ImageGenButton_url + '/'
                + width + '/'
                + height + '/'
                + bg + '/'
                + color + '/'
                + text);
              img.setAttribute("class", 'img-gen');
              instance.insertElement(img);
            }
          };
        });

        editor.addCommand('ImageGenCommand', new CKEDITOR.dialogCommand('ImageGenDialog',
          {allowedContent: 'img'}
        ));

        editor.ui.addButton('ImageGenButton',
          {
            label: 'ImageGen',
            command: 'ImageGenCommand',
            icon: this.path + 'icons/ImageGenIcon.png'
          });
      }
    });
})();
